<?php
require_once(dirname(__FILE__).'/cp-common.inc.php');
// cp-common handles request initialization and authentication.


define("PDATADIR", "/usr/local/nagios/share/perfdata");

define('CAPACITYBIN', get_base_dir().'/includes/components/capacityplanning/backend/capacityplanning.py');
define('TIMEFRAMEBIN', get_base_dir().'/includes/components/capacityplanning/backend/timeframe.py');


route_request();

function route_request()
{
    $cmd = grab_request_var('cmd', null);

    switch ($cmd) {
        case 'timeframe':
            $host    = grab_request_var('host',    null);
            $service = grab_request_var('service', null);
            $track   = grab_request_var('track',   null);
            $result = get_timeframe($host, $service, $track);
            break;
        case 'extrapolate':
            $host    = grab_request_var('host',    null);
            $service = grab_request_var('service', null);
            $track   = grab_request_var('track',   null);
            $options = grab_request_var('options', array());
            $result = get_extrapolation($host, $service, $track, $options);
            break;
        default:
            $result = '{"error": "Unknown command."}';
            break;
    }

    header('Content-type: application/json');
    print $result;
}

function get_timeframe($host, $service, $track)
{
    $host    = escapeshellarg(pnp_sanitize_filename($host));
    $service = escapeshellarg(pnp_sanitize_filename($service));
    $track   = escapeshellarg(pnp_sanitize_filename($track));

    $cmd = TIMEFRAMEBIN." $host $service $track 2>&1";

    $output = array();
    exec($cmd, $output, $returncode);

    return $output ? $output[0] : '';
}

function get_extrapolation($host, $service, $track, $options)
{
    $host    = escapeshellarg(pnp_sanitize_filename($host));
    $service = escapeshellarg(pnp_sanitize_filename($service));
    $track   = escapeshellarg(pnp_sanitize_filename($track));

    $cmd = CAPACITYBIN." -H $host -S $service -T $track";

    // Process any options and add them to our command string.
    if ($options && is_array($options)) {

        // Process dates options (potentially a combination of one or more
        // timestamps or date strings as a comma separated list or array).
        process_options_dates_to_times($options, 'dates');
        process_options_dates_to_times($options, 'times');

        // The switches we accept: URL param => CLI switch.
        $switches['period'] = ' -P ';
        $switches['steps']  = ' -s ';
        $switches['method'] = ' -M ';
        $switches['end']    = ' -E ';
        $switches['dates']  = ' -d ';
        $switches['times']  = ' -t ';
        $switches['rrddir'] = ' -rrddir';

        foreach ($options as $key => $value) {
            if (array_key_exists($key, $switches)) {
                $cmd .= $switches[$key] . escapeshellarg($value);
            }
        }
    }

    $output = array();
    exec($cmd, $output, $returncode);

    return $output ? $output[0] : '';
}

/**
 * Converts date/time options to UNIX timestamps.
 *
 * @param $options The input options key => value hashmap (array).
 * @param $key The option name to process if it exists in $options. The input
 * options are potentially a combination of one or more timestamps or date
 * strings (in PHP strtotime() format) as a comma separated list or array.
 * After processing the original $options[$key] will be replaced with a list of
 * UNIX timestamps for the original dates/times as a comma separated string.
 */
function process_options_dates_to_times(&$options, $key)
{
    // Process the option value for our key if it exists.
    if (array_key_exists($key, $options) && $options[$key]) {

        // Convert scalars to an array so we can treat them uniformly, and
        // also handle comma separated lists as input.
        if (!is_array($options[$key])) {
            $options[$key] = explode(',', $options[$key]);
        }

        // Now get a timestamp for each date. Explicitly convert numbers
        // to integers. We'll let strtotime() failures get converted to 0
        // and be handled by the backend as out of range dates.
        foreach ($options[$key] as &$date) {
            $date = intval(is_numeric($date) ? $date : strtotime($date));
        }

        // Now join all the times together as a comma separated list.
        $options[$key] = implode(',', $options[$key]);
    }
}
