<?php
require_once(dirname(__FILE__).'/../componenthelper.inc.php');
require_once('cp-common.inc.php');

// initialization stuff
pre_init();

// start session
init_session();

// grab GET or POST variables 
grab_request_vars();

// check prereqs
check_prereqs();

// check authentication
check_authentication(false);

define("PDATADIR", "/usr/local/nagios/share/perfdata");

route_request();

function route_request()
{
    global $request;
    
    $host = grab_request_var('host', null);
    $service = grab_request_var('service', null);
    
    if($host === null) {
        /**
         * If the host is set to null, then we need to get a list of 
         * possible hosts. Please note this will only return hosts that
         * have registered perfdata.
         */
        get_host_list();
    }
    else if($service === null) {
        /**
         * If the host is not null, but the service is, we need to 
         * return the available service list for the host.
         */
        get_service_list($host);
    } else if($service !== null && $host !== null) {
        /**
         * How we just need the track info for the service. Since this
         * is directly applicable to whats in the RRD, we are going
         * to look at whats in the RRD tracks.
         */
        get_track_list($host, $service);
    }
}

/**
 * Returns a list of avaiable hosts.
 */
function get_host_list()
{
    $hosts=array();

    $args=array('brevity' => 1,
                'orderby' => 'host_name:a',
                ); 
    
    $oxml=get_xml_host_objects($args);
    
    if($oxml){
        foreach($oxml->host as $hostobject){
            $name = strval($hostobject->host_name);
            $hosts[] = $name;
        }
    }
    
    $final = array();
    foreach($hosts as $host) {
        $s_host = pnp_sanitize_filename($host);
        $dir = PDATADIR."/{$s_host}";
        if(is_dir($dir)) {
            $final[] = $host;
        }
    }
    
    header('Content-type: application/json');
    print json_encode($final);
}

/**
 * Returns a list of available services for a host.
 */
function get_service_list($host)
{
    $services=array();
    $s_host = pnp_sanitize_filename($host);

    $args=array(
        'brevity' => 1,
        'host_name' => $host,
        'orderby' => 'name:a',
        );
    
    $oxml = get_xml_service_objects($args);
    
    if($oxml){
        $services[] = '_HOST_';
        foreach($oxml->service as $svcobject){
            $name = strval($svcobject->service_description);
            $services[] = $name;
        }
    }
    
    $final = array();
    foreach($services as $service) {
        $s_service = pnp_sanitize_filename($service);
        $rrd = PDATADIR."/{$s_host}/{$s_service}.rrd";
        if(is_file($rrd)) {
            $final[] = $service;
        }
    }
    
    header('Content-type: application/json');
    print json_encode($final);
}

/**
 * Returns a list of tracks available to this service.
 */
function get_track_list($host, $service)
{
    $host = pnp_sanitize_filename($host);
    $service = pnp_sanitize_filename($service);
    $tracks = array();
    
    $xmlfile = PDATADIR."/{$host}/{$service}.xml";
    
    $xml = simplexml_load_file($xmlfile);
    foreach($xml->DATASOURCE as $ds) {
        $tracks[] = (string)$ds->NAME;
    }
    
    header('Content-type: application/json');
    print json_encode($tracks);
}
